import neopixel, board, time, random, mount_sd, pwmio
from adafruit_motor import servo
from audiomp3 import MP3Decoder
from audiopwmio import PWMAudioOut as AudioOut
import adafruit_mpr121
from adafruit_debouncer import Button
from audiocore import WaveFile

audio = AudioOut(board.GP16)

fire_strip = neopixel.NeoPixel(board.GP17, 30, brightness = 1, auto_write=True)
winner_strip = neopixel.NeoPixel(board.GP18, 20, brightness = 1, auto_write=True)
from adafruit_led_animation.color import (
    AMBER, #(255, 100, 0)
    AQUA, # (50, 255, 255)
    BLACK, #OFF (0, 0, 0)
    BLUE, # (0, 0, 255)
    CYAN, # (0, 255, 255)
    GOLD, # (255, 222, 30)
    GREEN, # (0, 255, 0)
    JADE, # (0, 255, 40)
    MAGENTA, #(255, 0, 20)
    OLD_LACE, # (253, 245, 230)
    ORANGE, # (255, 40, 0)
    PINK, # (242, 90, 255)
    PURPLE, # (180, 0, 255)
    RED, # (255, 0, 0)
    TEAL, # (0, 255, 120)
    WHITE, # (255, 255, 255)
    YELLOW, # (255, 150, 0)
    RAINBOW # a list of colors to cycle through
    # RAINBOW is RED, ORANGE, YELLOW, GREEN, BLUE, and PURPLE ((255, 0, 0), (255, 40, 0), (255, 150, 0), (0, 255, 0), (0, 0, 255), (180, 0, 255))
)

INDIGO = (63, 0, 255)
VIOLET = (127, 0, 255)

# We often use these colors, but be sure to check colors used when taking exams
colors = [RED, MAGENTA, ORANGE, YELLOW, GREEN, JADE, TEAL, BLUE, INDIGO, VIOLET, PURPLE, WHITE]
winner_color = [BLUE, GREEN]

def breath_fire():
    for i in reversed(range(30)):
        fire_strip[i]=ORANGE
        time.sleep(.02)
    for i in range(5):
        fire_strip.fill(RED)
        time.sleep(.05)
        fire_strip.fill(YELLOW)
        time.sleep(.05)
    fire_strip.fill(BLACK)
    time.sleep(.1)
def breath_blue_fire():
    for i in reversed(range(30)):
        fire_strip[i]=BLUE
        time.sleep(.02)
    for i in range(5):
        fire_strip.fill(PURPLE)
        time.sleep(.05)
        fire_strip.fill(WHITE)
        time.sleep(.05)
    fire_strip.fill(BLACK)
    time.sleep(.1)
fire_strip.fill(BLACK)

def flash_winner_strip():
    random_color = random.choice(winner_color)
    for _ in range(8):
        winner_strip.fill(random_color)
        time.sleep(0.1)
        winner_strip.fill(BLACK)
        time.sleep(0.1)
    winner_strip.fill(WHITE)
winner_strip.fill(WHITE)

#set up i2c object
i2c = board.STEMMA_I2C()
touch_pad = adafruit_mpr121.MPR121(i2c)

pwm1 = pwmio.PWMOut(board.GP14, frequency=50)
servo_1 = servo.Servo(pwm1, min_pulse = 750, max_pulse = 2500)
pwm2 = pwmio.PWMOut(board.GP15, frequency=50)
servo_2 = servo.Servo(pwm2, min_pulse = 750, max_pulse = 2500)

# Example usage
start_angle = 0
end_angle = 180
step = 5
delay = 0.01  # Adjust this value to control the movement speed

def move_servos_face_to_face(servo1, servo2, start_angle, end_angle, step, delay):
    # Move servos from start_angle to end_angle in steps of step degrees
    for angle in range(start_angle, end_angle + 1, step):
        servo1.angle = angle
        servo2.angle = end_angle - angle + start_angle
        time.sleep(delay)

    # Move servos back to start_angle in steps of step degrees
    for angle in range(end_angle, start_angle - 1, -step):
        servo1.angle = angle
        servo2.angle = end_angle - angle + start_angle
        time.sleep(delay)


path = "/sd/dragonSounds/"
is_playing = False

sounds1 = ["dragon-growl.wav", "dragon-howl.wav", "dragon-roar.wav", "fire-breath.wav"]
sounds2 = ["dragon-growl.wav", "dragon-howl.wav", "dragon-roar.wav"]

def play_sound1(filename):
    with open(path + filename, "rb") as wave_file:
        wave = WaveFile(wave_file)
        audio.play(wave)
        while audio.playing:
            move_servos_face_to_face(servo_1, servo_2, start_angle, end_angle, step, delay)
        servo_1.angle = start_angle
        servo_2.angle = start_angle

def play_sound2(filename):
    with open(path + filename, "rb") as wave_file:
        wave = WaveFile(wave_file)
        audio.play(wave)
        while audio.playing:
            breath_fire()

def play_sound3(filename):
    with open(path + filename, "rb") as wave_file:
        wave = WaveFile(wave_file)
        audio.play(wave)
        while audio.playing:
            breath_blue_fire()


while True:
    if touch_pad[0].value:
        print("TOUCHBAD 0 PRESSED")
        random_sound1 = random.choice(sounds2)
        play_sound1(random_sound1)
        flash_winner_strip()
    if touch_pad[5].value:
        print("TOUCHBAD 5 PRESSED")
        random_sound2 = random.choice(sounds1)
        play_sound2(random_sound2)
    if touch_pad[6].value:
        print("TOUCHBAD 6 PRESSED")
        random_sound3 = random.choice(sounds1)
        play_sound3(random_sound3)
